@@ -1,10 +1,22 @@
+"""
+kombu.compat
+============
+
+Carrot compatible interface for :class:`Publisher` and :class:`Producer`.
+
+See http://packages.python.org/pypi/carrot for documentation.
+
+:copyright: (c) 2009 - 2010 by Ask Solem.
+:license: BSD, see LICENSE for more details.
+
+"""
 from itertools import count
 
 from kombu import entity
 from kombu import messaging
 
 
-def iterconsume(connection, consumer, no_ack=False, limit=None):
+def _iterconsume(connection, consumer, no_ack=False, limit=None):
     consumer.consume(no_ack=no_ack)
     for iteration in count(0):
         if limit and iteration >= limit:
@@ -161,7 +173,7 @@ class Consumer(messaging.Consumer):
         return self.purge()
 
     def iterconsume(self, limit=None, no_ack=None):
-        return iterconsume(self.connection, self, no_ack, limit)
+        return _iterconsume(self.connection, self, no_ack, limit)
 
     def wait(self, limit=None):
         it = self.iterconsume(limit)
@@ -176,15 +188,25 @@ class Consumer(messaging.Consumer):
             yield item
 
 
-class _CSet(messaging.Consumer):
+class ConsumerSet(messaging.Consumer):
 
-    def __init__(self, connection, *args, **kwargs):
+    def __init__(self, connection, from_dict=None, consumers=None,
+            callbacks=None, **kwargs):
         self.connection = connection
         self.backend = connection.channel()
-        super(_CSet, self).__init__(self.backend, *args, **kwargs)
+
+        queues = []
+        if consumers:
+            for consumer in consumers:
+                map(queues.extend, consumer.queues)
+        if from_dict:
+            for queue_name, queue_options in from_dict.items():
+                queues.append(entry_to_queue(queue_name, **queue_options))
+
+        super(ConsumerSet, self).__init__(self.backend, queues, **kwargs)
 
     def iterconsume(self, limit=None, no_ack=False):
-        return iterconsume(self.connection, self, no_ack, limit)
+        return _iterconsume(self.connection, self, no_ack, limit)
 
     def discard_all(self):
         return self.purge()
@@ -200,17 +222,3 @@ class _CSet(messaging.Consumer):
     def close(self):
         self.cancel()
         self.channel.close()
-
-
-def ConsumerSet(connection, from_dict=None, consumers=None,
-        callbacks=None, **kwargs):
-
-    queues = []
-    if consumers:
-        for consumer in consumers:
-            map(queues.extend, consumer.queues)
-    if from_dict:
-        for queue_name, queue_options in from_dict.items():
-            queues.append(entry_to_queue(queue_name, **queue_options))
-
-    return _CSet(connection, queues, **kwargs)
