@@ -1,3 +1,13 @@
+"""
+kombu.transport.memory
+======================
+
+In-memory transport.
+
+:copyright: (c) 2009 - 2010 by Ask Solem.
+:license: BSD, see LICENSE for more details.
+
+"""
 from Queue import Queue
 
 from kombu.transport import virtual
@@ -31,3 +41,6 @@ class Channel(virtual.Channel):
 
 class Transport(virtual.Transport):
     Channel = Channel
+
+    #: memory backend state is global.
+    state = virtual.BrokerState()
