@@ -1,3 +1,8 @@
+import pickle
+import sys
+import tempfile
+
+from pprint import pformat
 from time import sleep
 from uuid import UUID, uuid4, _uuid_generate_random
 
@@ -7,6 +12,10 @@ except ImportError:
     ctypes = None
 
 
+def say(m, *s):
+    sys.stderr.write(str(m) % s + "\n")
+
+
 def gen_unique_id():
     """Generate a unique id, having - hopefully - a very small chance of
     collission.
@@ -45,7 +54,7 @@ def repeatlast(it):
     yield the last value infinitely."""
     for item in it:
         yield item
-    while 1: # pragma: no cover
+    while 1:    # pragma: no cover
         yield item
 
 
@@ -92,6 +101,22 @@ def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
             return retval
 
 
+def emergency_dump_state(state):
+    persist = tempfile.mktemp()
+    say("EMERGENCY DUMP STATE TO FILE -> %s <-" % persist)
+    fh = open(persist, "w")
+    try:
+        try:
+            pickle.dump(state, fh, protocol=0)
+        except Exception, exc:
+            say("Cannot pickle state: %r. Fallback to pformat." % (exc, ))
+            fh.write(pformat(state))
+    finally:
+        fh.flush()
+        fh.close()
+    return persist
+
+
 ############## str.partition/str.rpartition #################################
 
 def _compat_rl_partition(S, sep, direction=None, reverse=False):
